timeintervaltools.resolve_overlaps_between_nonoverlapping_trees
===============================================================

.. autofunction:: abjad.tools.timeintervaltools.resolve_overlaps_between_nonoverlapping_trees.resolve_overlaps_between_nonoverlapping_trees
